from http import HTTPStatus
from typing import Any, Dict, List, Optional, Union

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.list_tokens_response_200_item import ListTokensResponse200Item
from ...types import UNSET, Response, Unset


def _get_kwargs(
    *,
    exclude_ephemeral: Union[Unset, None, bool] = UNSET,
) -> Dict[str, Any]:
    pass

    params: Dict[str, Any] = {}
    params["exclude_ephemeral"] = exclude_ephemeral

    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    return {
        "method": "get",
        "url": "/users/tokens/list",
        "params": params,
    }


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[List["ListTokensResponse200Item"]]:
    if response.status_code == HTTPStatus.OK:
        response_200 = []
        _response_200 = response.json()
        for response_200_item_data in _response_200:
            response_200_item = ListTokensResponse200Item.from_dict(response_200_item_data)

            response_200.append(response_200_item)

        return response_200
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[List["ListTokensResponse200Item"]]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    *,
    client: Union[AuthenticatedClient, Client],
    exclude_ephemeral: Union[Unset, None, bool] = UNSET,
) -> Response[List["ListTokensResponse200Item"]]:
    """list token

    Args:
        exclude_ephemeral (Union[Unset, None, bool]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[List['ListTokensResponse200Item']]
    """

    kwargs = _get_kwargs(
        exclude_ephemeral=exclude_ephemeral,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    *,
    client: Union[AuthenticatedClient, Client],
    exclude_ephemeral: Union[Unset, None, bool] = UNSET,
) -> Optional[List["ListTokensResponse200Item"]]:
    """list token

    Args:
        exclude_ephemeral (Union[Unset, None, bool]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        List['ListTokensResponse200Item']
    """

    return sync_detailed(
        client=client,
        exclude_ephemeral=exclude_ephemeral,
    ).parsed


async def asyncio_detailed(
    *,
    client: Union[AuthenticatedClient, Client],
    exclude_ephemeral: Union[Unset, None, bool] = UNSET,
) -> Response[List["ListTokensResponse200Item"]]:
    """list token

    Args:
        exclude_ephemeral (Union[Unset, None, bool]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[List['ListTokensResponse200Item']]
    """

    kwargs = _get_kwargs(
        exclude_ephemeral=exclude_ephemeral,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    *,
    client: Union[AuthenticatedClient, Client],
    exclude_ephemeral: Union[Unset, None, bool] = UNSET,
) -> Optional[List["ListTokensResponse200Item"]]:
    """list token

    Args:
        exclude_ephemeral (Union[Unset, None, bool]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        List['ListTokensResponse200Item']
    """

    return (
        await asyncio_detailed(
            client=client,
            exclude_ephemeral=exclude_ephemeral,
        )
    ).parsed
